@@ -38,15 +38,11 @@ def exists(path, use_sudo=False, verbose=False):
 def first(*args, **kwargs):
     """
     Given one or more file paths, returns first one found, or None if none
-    exist. May specify ``use_sudo`` which is passed to `exists`.
+    exist. May specify ``use_sudo`` and ``verbose`` which are passed to `exists`.
     """
     for directory in args:
-        if not kwargs.get('use_sudo'):
-            if exists(directory, sudo=False):
-                return directory
-        else:
-            if exists(directory):
-                return directory
+        if exists(directory, **kwargs):
+            return directory
 
 
 def upload_template(filename, destination, context=None, use_jinja=False,
