@@ -1,9 +1,9 @@
 from __future__ import with_statement
 
-from nose.tools import eq_
+from nose.tools import eq_, ok_
 
-from fabric.state import env
-from fabric.context_managers import cd, settings
+from fabric.state import env, output
+from fabric.context_managers import cd, settings, lcd
 
 
 #
@@ -44,14 +44,15 @@ def test_cwd_with_absolute_paths():
 # settings()
 #
 
-def test_setting_new_env_dict_key_should_not_raise_keyerror():
+def test_setting_new_env_dict_key_should_work():
     """
-    Using settings() with a previously nonexistent key should not error
+    Using settings() with a previously nonexistent key should work correctly
     """
-    # Nose has no obvious way to assert a NON-RAISED exception :( so ye olde
-    # "if it runs it passes" will have to do.
-    with settings(thiskeyreallyshouldnotexist='value'):
-        pass
+    key = 'thisshouldnevereverexistseriouslynow'
+    value = 'a winner is you'
+    with settings(**{key: value}):
+        ok_(key in env)
+    ok_(key not in env)
 
 
 def test_settings():
@@ -74,3 +75,19 @@ def test_settings_with_multiple_kwargs():
         eq_(env.testval2, "inner 2")
     eq_(env.testval1, "outer 1")
     eq_(env.testval2, "outer 2")
+
+def test_settings_with_other_context_managers():
+    """
+    settings() should take other context managers, and use them with other overrided
+    key/value pairs.
+    """
+    env.testval1 = "outer 1"
+    prev_lcwd = env.lcwd
+
+    with settings(lcd("here"), testval1="inner 1"):
+        eq_(env.testval1, "inner 1")
+        ok_(env.lcwd.endswith("here")) # Should be the side-effect of adding cd to settings
+
+    ok_(env.testval1, "outer 1")
+    eq_(env.lcwd, prev_lcwd)
+
